# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/love/phone/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Love\\Phone\\": "packages/love/phone/src",
            "Love\\Phone\\Seeders\\": "packages/love/phone/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Love\Phone\Providers\PhoneServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Phone'  => Love\Phone\Facades\Phone::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Love\\Phone\\Seeders\\PhoneTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Love\Phone\Providers\PhoneServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Love\Phone\Providers\PhoneServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Love\Phone\Providers\PhoneServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/phone/{modulename}

**User**

    http://path-to-route-folder/user/phone/{modulename}

**Public**

    http://path-to-route-folder/phones


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/phone/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/phone/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/phone/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/phone/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/phone/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/phone/{modulename}/{slug}
    METHOD: GET